from pkg_resources import get_distribution

try:
    __version__ = get_distribution('minos').version
except:
    __version__ = 'local'


__all__ = [
    'adjudicator',
    'dependencies',
    'genotyper',
    'gramtools',
    'mapping_based_verifier',
    'tasks',
    'utils',
]

from minos import *



from minos import mapping_based_verifier

def run(options):
    verifier = mapping_based_verifier.MappingBasedVerifier(
        options.vcf_file,
        options.vcf_ref,
        options.truth_ref,
        options.outprefix,
        flank_length=options.flank_length,
        expected_variants_vcf=options.expected_variants_vcf,
        run_dnadiff=options.run_dnadiff,
    )
    verifier.run()




from minos import adjudicator

def run(options):
    print(options.reads)
    adj = adjudicator.Adjudicator(
        options.outdir,
        options.ref_fasta,
        options.reads,
        options.vcf_files,
        max_read_length=options.max_read_length,
        read_error_rate=options.read_error_rate,
        overwrite_outdir=options.force,
        max_snps_per_cluster=options.max_snps_per_cluster,
        max_ref_len=options.max_ref_len,
    )
    adj.run()

